@@ -173,12 +173,12 @@ function(times = NULL, format = "h:m:s", length. = 0, ...)
     fmt <- parse.format(format)
     out <- unpaste(times, sep = fmt$sep, fnames = fmt$periods, nfields = 3)
     hh <- mm <- ss <- as.numeric(rep(NA, length(out$h)))
-    ok <- out$h != "NA" & out$m != "NA" & out$s != "NA"
+    ok <- !is.na(out$h) & !is.na(out$m) & !is.na(out$s)
     hh[ok] <- as.numeric(out$h[ok])
     mm[ok] <- as.numeric(out$m[ok])
     ss[ok] <- as.numeric(out$s[ok])
     if(all(is.na(hh) | is.na(mm) | is.na(ss)))
-        if(any(times != "NA"))
+        if(any(!is.na(times)))
             stop(paste("format", format, "may be incorrect"))
         else return(rep(NA, length(times)))
     i <- (hh[ok] < 0 | hh[ok] > 23 | mm[ok] < 0 | mm[ok] > 59 |
